==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Points/Gui/Resources/translations/Points_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="+187"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Convert to points...</source>
      <translation>Конвертувати в точки...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Convert to points</source>
      <translation>Конвертувати в точки</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location line="-80"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Експорт точок...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Exports a point cloud</source>
      <translation>Експорт хмари точок</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-51"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Імпорт точок...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Imports a point cloud</source>
      <translation>Імпорт хмари точок</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location line="+245"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Merge point clouds</source>
      <translation type="unfinished">Merge point clouds</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Merge several point clouds into one</source>
      <translation type="unfinished">Merge several point clouds into one</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="-49"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Вирізати хмару точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Вирізати точки у виділеній області</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-122"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Перетворення точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Test to transform a point cloud</source>
      <translation>Випробування для перетворення хмари точок</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>Імпорт точок ASCII</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Шаблон:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Спеціальні лінії</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Перший рядок:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Ігнорувати</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Скупчення по лінії, починаючи з:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Ігнорувати рядки, що починаються з:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Формат точки</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Номер роздільника:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Формат точок:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Наступний блок:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>немає</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (нормальний вектор)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (нормальний вектор 2D)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (колір)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation>I (Значення сірого)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Попередній перегляд</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Кількість точок</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation>Кількість ліній в попередньому перегляді:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>Ascii точки (*.asc);;Всі файли (*.*)</translation>
    </message>
    <message>
      <source>Ascii Points</source>
      <translation type="unfinished">Ascii Points</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-76"/>
      <location line="+50"/>
      <source>All Files</source>
      <translation>Всі файли</translation>
    </message>
    <message>
      <location line="-50"/>
      <location line="+50"/>
      <source>Point formats</source>
      <translation type="unfinished">Point formats</translation>
    </message>
    <message>
      <location line="+71"/>
      <source>Distance</source>
      <translation>Відстань</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Enter maximum distance:</source>
      <translation type="unfinished">Enter maximum distance:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Інструменти точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation>&amp;Точки</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Points/Gui/Resources/translations/Points_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="uk" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="+188"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Convert to points...</source>
      <translation>Конвертувати в точки...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Convert to points</source>
      <translation>Конвертувати в точки</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location line="-80"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Експорт точок...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Exports a point cloud</source>
      <translation>Експорт хмари точок</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-51"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Імпорт точок...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Imports a point cloud</source>
      <translation>Імпорт хмари точок</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location line="+249"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Merge point clouds</source>
      <translation>Об'єднання хмарки точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Merge several point clouds into one</source>
      <translation>Об'єднати декілька груп точок в одну</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="-49"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Вирізати хмару точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Вирізати точки у виділеній області</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-126"/>
      <source>Points</source>
      <translation>Точки</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Перетворення точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+2"/>
      <source>Test to transform a point cloud</source>
      <translation>Випробування для перетворення хмари точок</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>Імпорт точок ASCII</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Шаблон:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Спеціальні лінії</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Перший рядок:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Ігнорувати</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Скупчення по лінії, починаючи з:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Ігнорувати рядки, що починаються з:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Формат точки</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Номер роздільника:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Формат точок:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Наступний блок:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>немає</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation>I,J,K (нормальний вектор)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I,K (нормальний вектор 2D)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (колір)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation>I (Значення сірого)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Попередній перегляд</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Кількість точок</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation>Кількість ліній в попередньому перегляді:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>Ascii точки (*.asc);;Всі файли (*.*)</translation>
    </message>
    <message>
      <source>Ascii Points</source>
      <translation>Ascii точки</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-76"/>
      <location line="+50"/>
      <source>All Files</source>
      <translation>Всі файли</translation>
    </message>
    <message>
      <location line="-50"/>
      <location line="+50"/>
      <source>Point formats</source>
      <translation>Формат точок</translation>
    </message>
    <message>
      <location line="+71"/>
      <source>Distance</source>
      <translation>Відстань</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Enter maximum distance:</source>
      <translation>Введіть максимальну відстань:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Інструменти точок</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation>&amp;Точки</translation>
    </message>
  </context>
</TS>
